all.Tacsm<-function(){
     cat("\n")
     note_for_Tacsm_input()
     cat("\n")
     note_for_close_window()
     TacSMMpar<-data.frame(parameter=c("Hem","Alb","Dil","Flu","D (mg)","tau (hr)"),value=c(0))
     TacSMMpar<-edit(TacSMMpar)
##     TacSMMpar<-ycheck(TacSMMpar)
     cat("\n")
     note_for_Tacsm_conc_input()
     cat("\n")
     note_for_close_window()
     TacSMpar<-data.frame(ts=c(0),conc=c(0))
     TacSMpar<-edit(TacSMpar)
     TacSMpar<-mscheck(TacSMpar)
     cat("\n")
     Tac.sm(length(TacSMpar$ts),TacSMpar$conc,TacSMpar$ts,TacSMMpar[6,2],TacSMMpar[5,2],TacSMMpar[1,2],TacSMMpar[2,2],TacSMMpar[3,2],TacSMMpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Tacsm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Taccpr(4.5,TacSMMpar[5,2],TacSMMpar[6,2],TacSMMpar[6,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mcg/mL)")
     show(coutput)    
     cat("\n")      
     Tac.more()
}